@@ -20,7 +20,7 @@ from code_loader.utils import to_numpy_return_wrapper, get_shape
 from code_loader.visualizers.default_visualizers import DefaultVisualizer, \
     default_graph_visualizer, \
     default_image_visualizer, default_horizontal_bar_visualizer, default_word_visualizer, \
-    default_image_mask_visualizer, default_text_mask_visualizer, default_raw_data_visualizer
+    default_image_mask_visualizer, default_text_mask_visualizer, default_raw_data_visualizer, default_video_visualizer
 
 
 class LeapBinder:
@@ -48,6 +48,8 @@ class LeapBinder:
     def _extend_with_default_visualizers(self) -> None:
         self.set_visualizer(function=default_image_visualizer, name=DefaultVisualizer.Image.value,
                             visualizer_type=LeapDataType.Image)
+        self.set_visualizer(function=default_video_visualizer, name=DefaultVisualizer.Video.value,
+                            visualizer_type=LeapDataType.Video)
         self.set_visualizer(function=default_graph_visualizer, name=DefaultVisualizer.Graph.value,
                             visualizer_type=LeapDataType.Graph)
         self.set_visualizer(function=default_raw_data_visualizer, name=DefaultVisualizer.RawData.value,
@@ -557,7 +559,7 @@ class LeapBinder:
             for state, preprocess_response in preprocess_result.items():
                 if state == DataStateEnum.unlabeled and isinstance(dataset_base_handler, GroundTruthHandler):
                     continue
-                self.check_handler(preprocess_response, test_result, dataset_base_handler, state)
+                test_result = self.check_handler(preprocess_response, test_result, dataset_base_handler, state)
 
     def check(self) -> None:
         preprocess_result = self.get_preprocess_result()
